@font-face {
  font-family: DroidSerif;
  src: url("../fonts/DroidSerif.ttf");
}

@font-face {
  font-family: LeagueGothic;
  src: url("../fonts/LeagueGothic-Regular.otf");
}

body {
  color: #3C3C3C;
  margin: 0px;
  background: url("../images/background.png");
  font-size: 18px;
}

h1, h2, h3, h4, h5 {
  font-family: LeagueGothic, 'Liberation Sans', "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", Helvetica, Arial, sans-serif;
  color: black;
  font-weight: normal;
}

.navbar-brand {
    font-size: 32px;
  font-family: LeagueGothic, 'Liberation Sans', "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", Helvetica, Arial, sans-serif;
  color: black;
  font-weight: normal;
}

.tags {
    margin-top: 10px;
    margin-bottom: 10px;
    line-height: 1.8em;
    text-align: justify;
}

.description {
    background: white;
    border: 3px solid #DADADA;
    padding: 10px;
    border-radius: 3px;
}

.help-block {
    font-size: 0.7em;
}

body.test-add #title, input[name="title"] {
  font-family: LeagueGothic, 'Liberation Sans', "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", Helvetica, Arial, sans-serif;
  color: black;
  font-weight: normal;
  font-size: 32px;
  height: 2em;
}

body.test-add #description {
    height: 250px;
}

#add-this {
    margin-bottom: 10px;
}

#result {
    margin-top: 10px;
    margin-bottom: 10px;
}

#result .submit {
    margin-top: 5px;
    text-align: center;
}

div.tags ul {
    margin: 0px;
    padding: 0px;
    text-align: center;
}

div.tags ul li {
    margin: 0px;
    display: inline-block;
    padding: 5px;
    padding-right: 10px;
    padding-left: 10px;
    background: rgb(50, 118, 177);
    color: white;
    cursor: pointer;
    margin: 2px;
}

div.tags ul li[selected] {
    background: green;
}


body.run-detail .comment {
    font-size: 0.7em;
}