<li><a href="{% url "test-add" %}"><span class="glyphicon glyphicon-edit"></span> Create Test</a></li>
<li><a href="{% url "assistant-home" %}"><span class="glyphicon glyphicon-th-list"></span> List tests</a></li>
<li><a href="{% url "assistant-home" %}search"><span class="glyphicon glyphicon-search"></span> Search tests</a></li>
<li><a href="{% url "run-add" %}"><span class="glyphicon glyphicon-edit"></span> Create run</a></li>
<li><a href="{% url "run-list" %}"><span class="glyphicon glyphicon-th-list"></span> List runs</a></li>
