{% extends "assistant/base.html" %}

{%  block container %} 

<div class="col-md-6 col-md-offset-3">
	<form method="POST">
	  {% csrf_token %}
	  <div class="form-group">
	    <input name="title" type="text" class="form-control" placeholder="Title" value="{{ test.title }}">
	  </div>
	  <div class="tags">
	    <ul>
	      {% for tag in tags %}
		    <li {% if run.name in run.tags.names %}selected="selected"{% endif %}>{{ tag.name }}</li>
	      {% endfor %}
	    </ul>
      <input type="hidden" name="tags" value="{% for tag in run.tags.names %}{{ tag }},{% endfor %}" />
    </div>
	  <button type="submit" class="btn btn-primary btn-block">Submit</button>
	</form>
</div>

{% endblock %}
