{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tests assistant</title>
    <link href="{% static "css/bootstrap.css" %}" rel="stylesheet">
    <link href="{% static "css/app.css" %}" rel="stylesheet">
  </head>
  <body>
    <nav class="navbar navbar-default" role="navigation">
      <!-- Brand and toggle get grouped for better mobile display -->
      <div class="navbar-header">
        <a class="navbar-brand" href="{% url "assistant-home" %}">Tests Assistant</a>
      </div>

      <!-- Collect the nav links, forms, and other content for toggling -->
      <div class="collapse navbar-collapse navbar-ex1-collapse">
        <ul class="nav navbar-nav">
          {%  block navigation %}
	          {% include "assistant/navigation.html" %}
          {% endblock %}
        </ul>
      </div><!-- /.navbar-collapse -->
    </nav>    
    <div class="container">
      {%  block container %} {% endblock %}
    </div>
    <script src="{% static "js/jquery.js" %}"></script>
    <script src="{% static "js/bootstrap.js" %}"></script>
    <script src="{% static "js/app.js" %}"></script>
  </body>
</html>
